import { getFormattingDetails } from './internals';
/**
 * Format money based on settings
 * @param value - Monetary value to be formatted
 * @param settings - Formatting settings, currency code or currency
 * @returns - Formatted money string
 */
var format = function (value, settings) {
    var _a = getFormattingDetails(value, settings), symbol = _a.symbol, code = _a.code, decimalDigits = _a.decimalDigits, thousandsSeparator = _a.thousandsSeparator, decimalSeparator = _a.decimalSeparator, pattern = _a.pattern, formatter = _a.formatter, innerValue = _a.value;
    var formattedValue = innerValue.absoluteValue().toFormat(decimalDigits);
    var defaultFormatted = pattern
        .replace('%v', formattedValue)
        .replace('%ns', innerValue.isNegative() ? '-' : '')
        .replace('%i', innerValue.isInteger() ? innerValue.toFormat(0) : formattedValue)
        .replace('%s', symbol)
        .replace('%c', code);
    if (typeof formatter === 'function') {
        return formatter({
            value: value,
            defaultFormatted: defaultFormatted,
            symbol: symbol,
            code: code,
            decimalDigits: decimalDigits,
            thousandsSeparator: thousandsSeparator,
            decimalSeparator: decimalSeparator,
            pattern: pattern,
        });
    }
    return defaultFormatted;
};
export default format;
//# sourceMappingURL=index.js.map