import BigNumber from 'bignumber.js';
/**
 * Rounding modes you can use in your operations.
 * These map directly to
 * [`BigNumber`'s rounding modes](http://mikemcl.github.io/bignumber.js/#constructor-properties).
 *
 * @example
 * Rounding mode usage
 * ```js
 * const
 *      price = new Money('7856', 'USD'), // $78.56
 *      discountedAndRoundedUp = price.multiply('0.70'), // $55.00
 *      discountedAndRoundedDown = price.multiply('0.70', ROUNDING.DOWN); // $54.99
 * ```
 */
var ROUNDING;
(function (ROUNDING) {
    /**
     * Rounds away from zero
     */
    ROUNDING[ROUNDING["UP"] = BigNumber.ROUND_UP] = "UP";
    /**
     * Rounds towards zero
     */
    ROUNDING[ROUNDING["DOWN"] = BigNumber.ROUND_DOWN] = "DOWN";
    /**
     * Rounds towards Infinity
     */
    ROUNDING[ROUNDING["CEIL"] = BigNumber.ROUND_CEIL] = "CEIL";
    /**
     * Rounds towards Infinity
     */
    ROUNDING[ROUNDING["FLOOR"] = BigNumber.ROUND_FLOOR] = "FLOOR";
    /**
     * Rounds towards nearest neighbour.
     * If equidistant, rounds away from zero
     */
    ROUNDING[ROUNDING["HALF_UP"] = BigNumber.ROUND_HALF_UP] = "HALF_UP";
    /**
     * Rounds towards nearest neighbour.
     * If equidistant, rounds towards zero
     */
    ROUNDING[ROUNDING["HALF_DOWN"] = BigNumber.ROUND_HALF_DOWN] = "HALF_DOWN";
    /**
     * Rounds towards nearest neighbour.
     * If equidistant, rounds towards even neighbour
     */
    ROUNDING[ROUNDING["HALF_EVEN"] = BigNumber.ROUND_HALF_EVEN] = "HALF_EVEN";
    /**
     * Rounds towards nearest neighbour.
     * If equidistant, rounds towards Infinity
     */
    ROUNDING[ROUNDING["HALF_CEIL"] = BigNumber.ROUND_HALF_CEIL] = "HALF_CEIL";
    /**
     * Rounds towards nearest neighbour.
     * If equidistant, rounds towards Infinity
     */
    ROUNDING[ROUNDING["HALF_FLOOR"] = BigNumber.ROUND_HALF_FLOOR] = "HALF_FLOOR";
})(ROUNDING || (ROUNDING = {}));
export default ROUNDING;
//# sourceMappingURL=ROUNDING.js.map