"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _internals_1 = require("../_internals");
/**
 * Get formatting details
 * @param value - Monetary value to be formatted
 * @param settings - Formatting settings, currency code or currency
 * @returns - Formatting details
 * @private
 */
exports.getFormattingDetails = function (value, settings) {
    var _a = _internals_1.getCurrency(settings, value).settings, symbol = _a.symbol, code = _a.code, thousandsSeparator = _a.thousandsSeparator, decimalSeparator = _a.decimalSeparator, decimalDigits = _a.decimalDigits, pattern = _a.pattern, formatter = _a.formatter;
    var bigNumberValue;
    if (settings === undefined) {
        bigNumberValue = value.amountAsBigNumber;
    }
    else {
        var BN = value.bigNumberConstructor.clone({
            FORMAT: {
                decimalSeparator: decimalSeparator,
                groupSeparator: thousandsSeparator,
                groupSize: 3,
                secondaryGroupSize: 0,
                fractionGroupSeparator: ' ',
                fractionGroupSize: 0,
            },
        });
        bigNumberValue = new BN(value.amountAsBigNumber);
    }
    return {
        symbol: symbol,
        code: code,
        decimalDigits: decimalDigits,
        thousandsSeparator: thousandsSeparator,
        decimalSeparator: decimalSeparator,
        pattern: pattern,
        formatter: formatter,
        value: bigNumberValue,
    };
};
//# sourceMappingURL=internals.js.map